from .colors.gray import *
from .colors.blue import *
from .colors.cyan import *
from .colors.brown import *
from .colors.purple import *
from .colors.pink import *
from .colors.green import *
from .colors.red import *
from .colors.orange import *
from .colors.yellow import *
from .colors.ligthcolors import *

def stringColor(cor:str) -> str:

    '''
    Using StringColor:

    >>> import hexacolors
    >>> hexacolors.stringColor('Blue')
    >>> print(hexacolors.listall) #List all colors availables
    '''

    if cor.lower().replace(' ','') == 'black':return black()
    elif cor.lower().replace(' ','') == 'gray1':return grey11()
    elif cor.lower().replace(' ','') == 'gray2':return grey21()
    elif cor.lower().replace(' ','') == 'gray3':return grey31()
    elif cor.lower().replace(' ','') == 'dimgray':return dimgray()
    elif cor.lower().replace(' ','') == 'gray':return gray()
    elif cor.lower().replace(' ','') == 'darkgray':return darkgray()
    elif cor.lower().replace(' ','') == 'silver':return silver()
    elif cor.lower().replace(' ','') == 'ligthgrey':return ligthgrey()
    elif cor.lower().replace(' ','') == 'gainsboro':return gainsboro()
    elif cor.lower().replace(' ','') == 'slateblue':return slateblue()
    elif cor.lower().replace(' ','') == 'slateblue1':return slateblue1()
    elif cor.lower().replace(' ','') == 'slateblue2':return slateblue3()
    elif cor.lower().replace(' ','') == 'darkslateblue':return darkslateblue()
    elif cor.lower().replace(' ','') == 'midnightblue':return midnightblue()
    elif cor.lower().replace(' ','') == 'navy':return navy()
    elif cor.lower().replace(' ','') == 'darkblue':return darkblue()
    elif cor.lower().replace(' ','') == 'mediumblue':return mediumblue()
    elif cor.lower().replace(' ','') == 'blue':return blue()
    elif cor.lower().replace(' ','') == 'cornflowerblue':return cornflowerblue()
    elif cor.lower().replace(' ','') == 'royalblue':return royalblue()
    elif cor.lower().replace(' ','') == 'dodgerblue':return dodgerblue()
    elif cor.lower().replace(' ','') == 'deepskyblue':return deepskyblue()
    elif cor.lower().replace(' ','') == 'lightskyblue':return lightskyblue()
    elif cor.lower().replace(' ','') == 'skyblue':return skyblue()
    elif cor.lower().replace(' ','') == 'lightblue':return lightblue()
    elif cor.lower().replace(' ','') == 'steelblue':return steelblue()
    elif cor.lower().replace(' ','') == 'lightsteelblue':return lightsteelblue()
    elif cor.lower().replace(' ','') == 'slategray':return slategray()
    elif cor.lower().replace(' ','') == 'lightslategray':return lightslategray()
    elif cor.lower().replace(' ','') == 'cyan':return cyan()
    elif cor.lower().replace(' ','') == 'darkturquoise':return darkturquoise()
    elif cor.lower().replace(' ','') == 'turquoise':return turquoise()
    elif cor.lower().replace(' ','') == 'mediumturquoise':return mediumturquoise()
    elif cor.lower().replace(' ','') == 'lightseagreen':return lightseagreen()
    elif cor.lower().replace(' ','') == 'darkcyan':return darkcyan()
    elif cor.lower().replace(' ','') == 'teal':return teal()
    elif cor.lower().replace(' ','') == 'aquamarine':return aquamarine()
    elif cor.lower().replace(' ','') == 'mediumaquamarine':return mediumaquamarine()
    elif cor.lower().replace(' ','') == 'cadetblue':return cadetblue()
    elif cor.lower().replace(' ','') == 'darkkhaki':return darkkhaki()
    elif cor.lower().replace(' ','') == 'goldenrod':return goldenrod()
    elif cor.lower().replace(' ','') == 'darkgoldenrod':return darkgoldenrod()
    elif cor.lower().replace(' ','') == 'saddlebrown':return saddlebrown()
    elif cor.lower().replace(' ','') == 'sienna':return sienna()
    elif cor.lower().replace(' ','') == 'rosybrown':return rosybrown()
    elif cor.lower().replace(' ','') == 'peru':return peru()
    elif cor.lower().replace(' ','') == 'chocolate':return chocolate()
    elif cor.lower().replace(' ','') == 'sandybrown':return sandybrown()
    elif cor.lower().replace(' ','') == 'navajowhite':return navajowhite()
    elif cor.lower().replace(' ','') == 'wheat':return wheat()
    elif cor.lower().replace(' ','') == 'burlywood':return burlywood()
    elif cor.lower().replace(' ','') == 'tan':return tan()
    elif cor.lower().replace(' ','') == 'mediumslateBllue':return mediumslateBllue()
    elif cor.lower().replace(' ','') == 'mediumpurple':return mediumpurple()
    elif cor.lower().replace(' ','') == 'blueviolet':return blueviolet()
    elif cor.lower().replace(' ','') == 'indigo':return indigo()
    elif cor.lower().replace(' ','') == 'darkviolet':return darkviolet()
    elif cor.lower().replace(' ','') == 'darkorchid':return darkorchid()
    elif cor.lower().replace(' ','') == 'mediumorchid':return mediumorchid()
    elif cor.lower().replace(' ','') == 'purple':return purple()
    elif cor.lower().replace(' ','') == 'darkmagenta':return darkmagenta()
    elif cor.lower().replace(' ','') == 'magenta':return magenta()
    elif cor.lower().replace(' ','') == 'violet':return violet()
    elif cor.lower().replace(' ','') == 'orchid':return orchid()
    elif cor.lower().replace(' ','') == 'plum':return plum()
    elif cor.lower().replace(' ','') == 'mediumvioletred':return mediumvioletred()
    elif cor.lower().replace(' ','') == 'deeppink':return deeppink()
    elif cor.lower().replace(' ','') == 'hotpink':return hotpink()
    elif cor.lower().replace(' ','') == 'palevioletred':return palevioletred()
    elif cor.lower().replace(' ','') == 'lightpink':return lightpink()
    elif cor.lower().replace(' ','') == 'pink':return pink()
    elif cor.lower().replace(' ','') == 'lightcoral':return lightcoral()
    elif cor.lower().replace(' ','') == 'indianred':return indianred()
    elif cor.lower().replace(' ','') == 'crimson':return crimson()
    elif cor.lower().replace(' ','') == 'darkslategreen':return darkslategreen()
    elif cor.lower().replace(' ','') == 'mediumspringgreen':return mediumspringgreen()
    elif cor.lower().replace(' ','') == 'springgreen':return springgreen()
    elif cor.lower().replace(' ','') == 'palegreen':return palegreen()
    elif cor.lower().replace(' ','') == 'lightgreen':return lightgreen()
    elif cor.lower().replace(' ','') == 'darkseagreen':return darkseagreen()
    elif cor.lower().replace(' ','') == 'mediumseagreen':return mediumseagreen()
    elif cor.lower().replace(' ','') == 'seagreen':return seagreen()
    elif cor.lower().replace(' ','') == 'darkgreen':return darkgreen()
    elif cor.lower().replace(' ','') == 'green':return green()
    elif cor.lower().replace(' ','') == 'forestgreen':return forestgreen()
    elif cor.lower().replace(' ','') == 'limegreen':return limegreen()
    elif cor.lower().replace(' ','') == 'lime':return lime()
    elif cor.lower().replace(' ','') == 'lawngreen':return lawngreen()
    elif cor.lower().replace(' ','') == 'chartreuse':return chartreuse()
    elif cor.lower().replace(' ','') == 'greenyellow':return greenyellow()
    elif cor.lower().replace(' ','') == 'yellowgreen':return yellowgreen()
    elif cor.lower().replace(' ','') == 'olivedrab':return olivedrab()
    elif cor.lower().replace(' ','') == 'darkolivegreen':return darkolivegreen()
    elif cor.lower().replace(' ','') == 'olive':return olive()
    elif cor.lower().replace(' ','') == 'maroon':return maroon()
    elif cor.lower().replace(' ','') == 'darkred':return darkred()
    elif cor.lower().replace(' ','') == 'firebrick':return firebrick()
    elif cor.lower().replace(' ','') == 'brown':return brown() 
    elif cor.lower().replace(' ','') == 'salmon':return salmon()
    elif cor.lower().replace(' ','') == 'darksalmon':return darksalmon()
    elif cor.lower().replace(' ','') == 'lightsalmon':return lightsalmon()
    elif cor.lower().replace(' ','') == 'coral':return coral()
    elif cor.lower().replace(' ','') == 'tomato':return tomato()
    elif cor.lower().replace(' ','') == 'red':return red()
    elif cor.lower().replace(' ','') == 'orangered':return orangered()
    elif cor.lower().replace(' ','') == 'darkorange':return darkorange()
    elif cor.lower().replace(' ','') == 'orange':return orange()
    elif cor.lower().replace(' ','') == 'gold':return gold()
    elif cor.lower().replace(' ','') == 'yellow':return yellow()
    elif cor.lower().replace(' ','') == 'khaki':return khaki()
    elif cor.lower().replace(' ','') == 'white':return white()
    elif cor.lower().replace(' ','') == 'aliceblue':return aliceblue()
    elif cor.lower().replace(' ','') == 'ghostwhite':return ghostwhite()
    elif cor.lower().replace(' ','') == 'snow':return snow()
    elif cor.lower().replace(' ','') == 'seashell':return seashell()
    elif cor.lower().replace(' ','') == 'floralwhite':return floralwhite()
    elif cor.lower().replace(' ','') == 'whitesmoke':return whitesmoke()
    elif cor.lower().replace(' ','') == 'beige':return beige()
    elif cor.lower().replace(' ','') == 'oldlace':return oldlace()
    elif cor.lower().replace(' ','') == 'ivory':return ivory()
    elif cor.lower().replace(' ','') == 'linen':return linen()
    elif cor.lower().replace(' ','') == 'cornsilk':return cornsilk()
    elif cor.lower().replace(' ','') == 'antiquewhite':return antiquewhite()
    elif cor.lower().replace(' ','') == 'blanchedalmond':return blanchedalmond()
    elif cor.lower().replace(' ','') == 'bisque':return bisque()
    elif cor.lower().replace(' ','') == 'lightyellow':return lightyellow()
    elif cor.lower().replace(' ','') == 'lemonchiffon':return lemonchiffon()
    elif cor.lower().replace(' ','') == 'lightgoldenrodyellow':return lightgoldenrodyellow()
    elif cor.lower().replace(' ','') == 'papayawhip':return papayawhip()
    elif cor.lower().replace(' ','') == 'peachpuff':return peachpuff()
    elif cor.lower().replace(' ','') == 'moccasin':return moccasin()
    elif cor.lower().replace(' ','') == 'palegoldenrod':return palegoldenrod()
    elif cor.lower().replace(' ','') == 'mistyrose':return mistyrose()
    elif cor.lower().replace(' ','') == 'lavenderblush':return lavenderblush()
    elif cor.lower().replace(' ','') == 'lavender':return lavender()
    elif cor.lower().replace(' ','') == 'thistle':return thistle()
    elif cor.lower().replace(' ','') == 'azure':return azure()
    elif cor.lower().replace(' ','') == 'lightcyan':return lightcyan()
    elif cor.lower().replace(' ','') == 'powderblue':return powderblue()
    elif cor.lower().replace(' ','') == 'paleturquoise':return paleturquoise()
    elif cor.lower().replace(' ','') == 'honeydew':return honeydew()
    elif cor.lower().replace(' ','') == 'mintcream':return mintcream()