def cyan():return 0x00FFFF
def darkturquoise():return 0x00CED1
def turquoise():return 0x40E0D0
def mediumturquoise():return 0x48D1CC
def lightseagreen():return 0x20B2AA
def darkcyan():return 0x008B8B
def teal():return 0x008080
def aquamarine():return 0x7FFFD4
def mediumaquamarine():return 0x66CDAA
def cadetblue():return 0x5F9EA0